@@ -16,5 +16,5 @@ class Cli(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        o = OpenStack(settings.CONFIG_DIR, args['clouds'])
+        o = OpenStack(settings.CONFIG_DIR, **args)
         o.run(args['args'])
