@@ -1,10 +1,9 @@
-import copy
 import os
-import re
 import sh
 import shutil
 import textwrap
 import yaml
+from enough.common import ansible_utils
 
 
 class Hosts(object):
@@ -135,12 +134,15 @@ class DotEnough(object):
         """))
 
 
+class DotEnoughOpenStackUnknownProvider(Exception):
+    pass
+
+
 class DotEnoughOpenStack(DotEnough):
 
-    def __init__(self, config_dir, domain, provider):
+    def __init__(self, config_dir, domain):
         super().__init__(config_dir, domain)
         self.clouds_file = f'{self.config_dir}/inventory/group_vars/all/clouds.yml'
-        self.provider = provider
 
     def set_clouds_file(self, clouds_file):
         shutil.copy(clouds_file, self.clouds_file)
@@ -148,59 +150,36 @@ class DotEnoughOpenStack(DotEnough):
     def ensure(self):
         super().ensure()
         self.populate_config('letsencrypt')
-        self.set_missing_config_file_from_openrc(f'{self.config_dir}/openrc.sh', self.clouds_file)
 
-        d = f'{self.config_dir}/inventory/group_vars/all'
-        if not os.path.exists(f'{d}/openstack-provider.yml'):
-            open(f'{d}/openstack-provider.yml', 'w').write(textwrap.dedent(f"""\
-            ---
-            openstack_provider: {self.provider}
-            """))
+    def populate_provider(self, ansible, cloud):
+        try:
+            return ansible.get_global_variable('openstack_provider')
+        except ansible_utils.AnsibleVariableNotFound:
+            pass
 
-    @staticmethod
-    def set_missing_config_file_from_openrc(openrc, config_file):
-        if os.path.exists(openrc) and not os.path.exists(config_file):
-            DotEnoughOpenStack.openrc2clouds(openrc, config_file)
-            return True
-        else:
-            return False
+        try:
+            clouds = ansible.get_global_variable('clouds')
+        except ansible_utils.AnsibleVariableNotFound:
+            return None
 
-    @staticmethod
-    def openrc2clouds(openrc, clouds):
-        c = {
-            'auth': {
-                'user_domain_name': 'Default',
-                'password': 'PLACEHOLDER',
-            }
-        }
-        for line in open(openrc).readlines():
-            r = re.search(r'export\s+(OS_\w+)="(.*)"', line)
-            if not r:
-                r = re.search(r'export\s+(OS_\w+)=(.*)\s*', line)
-                if not r:
-                    continue
-            (k, v) = r.group(1, 2)
-            if k == 'OS_REGION_NAME':
-                c['region_name'] = v
-            elif k == 'OS_AUTH_URL':
-                c['auth']['auth_url'] = v
-            elif k == 'OS_PROJECT_NAME' or k == 'OS_TENANT_NAME':
-                c['auth']['project_name'] = v
-            elif k == 'OS_PROJECT_ID' or k == 'OS_TENANT_ID':
-                c['auth']['project_id'] = v
-            elif k == 'OS_USERNAME':
-                c['auth']['username'] = v
-            elif k == 'OS_PASSWORD' and v != '$OS_PASSWORD_INPUT':
-                c['auth']['password'] = v
-        clone = copy.deepcopy(c)
-        clone['region_name'] = 'DE1'
-        open(clouds, 'w').write(yaml.dump({
-            'clouds': {
-                'production': c,
-                'clone': clone,
-            }
-        }))
-        return c
+        url = clouds[cloud]['auth']['auth_url']
+        string2provider = (('ovh.net', 'ovh'),
+                           ('fuga.cloud', 'fuga'))
+        provider = None
+        for (string, found) in string2provider:
+            if string in url:
+                provider = found
+                break
+        if provider is None:
+            raise DotEnoughOpenStackUnknownProvider(
+                f'url {url} does not match any known providers {string2provider}')
+
+        f = f'{self.config_dir}/inventory/group_vars/all/openstack-provider.yml'
+        open(f, 'w').write(textwrap.dedent(f"""\
+        ---
+        openstack_provider: {provider}
+        """))
+        return f
 
 
 class DotEnoughDocker(DotEnough):
