@@ -112,8 +112,7 @@ class ServiceOpenStack(Service):
     def __init__(self, config_dir, share_dir, **kwargs):
         super().__init__(config_dir, share_dir, **kwargs)
         self.args = kwargs
-        self.dotenough = dotenough.DotEnoughOpenStack(config_dir, self.args['domain'],
-                                                      self.args['provider'])
+        self.dotenough = dotenough.DotEnoughOpenStack(config_dir, self.args['domain'])
         self.dotenough.ensure()
 
     def maybe_delegate_dns(self):
