@@ -10,8 +10,7 @@ class SSH(object):
         self.config_dir = config_dir
         self.args = kwargs
         self.dot = dotenough.DotEnoughOpenStack(self.config_dir,
-                                                self.args['domain'],
-                                                self.args['provider'])
+                                                self.args['domain'])
         self.dot.ensure()
 
     def ssh(self, host, args, interactive=True):
