@@ -21,8 +21,7 @@ class Create(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'],
-                                         args['provider'])
+        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'])
         d.ensure()
         o = OpenStack(settings.CONFIG_DIR, **args)
         o.backup_create(args['volumes'])
@@ -42,8 +41,7 @@ class Prune(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'],
-                                         args['provider'])
+        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'])
         d.ensure()
         o = OpenStack(settings.CONFIG_DIR, **args)
         o.backup_prune(args['days'])
