@@ -36,23 +36,20 @@ def get_hosts(session, enough):
 
 
 def pytest_sessionstart(session):
+    if session.config.getoption("--enough-no-create"):
+        return
+
     if not session.config.getoption("--enough-no-destroy"):
         enough_destroy(session)
 
     service_directory = session.config.getoption("--enough-service")
-    provider = session.config.getoption("--provider")
-    os.environ['ENOUGH_PROVIDER'] = provider
     domain = f'{service_directory}.test'
     enough_dot_dir = session.config.cache.makedir('dotenough')
     config_dir = prepare_config_dir(domain, enough_dot_dir)
 
-    if session.config.getoption("--enough-no-create"):
-        return
-
     e = Enough(config_dir, '.',
                domain=domain,
                driver='openstack',
-               provider=provider,
                inventory=[f'playbooks/{service_directory}/inventory'],
                route_to_internal=False)
     (vpn_host, hosts) = get_hosts(session, e)
@@ -95,7 +92,6 @@ def pytest_sessionfinish(session, exitstatus):
 
 def enough_destroy(session):
     service_directory = session.config.getoption("--enough-service")
-    provider = session.config.getoption("--provider")
     domain = f'{service_directory}.test'
     enough_dot_dir = session.config.cache.makedir('dotenough')
     config_dir = make_config_dir(domain, enough_dot_dir)
@@ -106,7 +102,6 @@ def enough_destroy(session):
     e = Enough(config_dir, '.',
                domain=domain,
                driver='openstack',
-               provider=provider,
                inventory=[f'playbooks/{service_directory}/inventory'])
     e.destroy()
 
