@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'openedx-host')
-        assert r['attrs']['name'] == 'openedx-host'
+        assert 'openedx-host' in self.get_hosts(host='openedx-host')
 
     def test_service(self, host):
         assert self.is_service_ok('openedx-host!openedX')
