@@ -1,5 +1,5 @@
-import time
 import testinfra
+from enough.common import retry
 
 testinfra_hosts = ['ansible://weblate-host']
 
@@ -11,6 +11,9 @@ def test_weblate_send_mail(host):
         'ansible://postfix-host',
         ansible_inventory=host.backend.ansible_inventory)
 
+    with postfix_host.sudo():
+        host.run("postsuper -d ALL")
+
     cmd = weblate_host.run("""
     cd /srv/weblate
     sudo docker-compose -f docker-compose-infrastructure.yml exec -T weblate weblate \
@@ -20,12 +23,12 @@ def test_weblate_send_mail(host):
     print(cmd.stderr)
     assert 0 == cmd.rc
 
-    check = ("grep -q 'connection established to spool.mail.gandi.net' "
-             "/var/log/mail.log")
-    for _ in range(300):
-        print(check)
-        cmd = postfix_host.run(check)
-        if cmd.rc == 0:
-            break
-        time.sleep(1)
-    assert 0 == postfix_host.run(check).rc
+    @retry.retry(AssertionError, tries=5)
+    def wait_for_mail():
+        with postfix_host.sudo():
+            cmd = postfix_host.run("""
+            grep -q doomtofail /var/spool/postfix/hold/*
+            """)
+        print(cmd.stdout)
+        assert cmd.rc == 0, f'{cmd.stdout} {cmd.stderr}'
+    wait_for_mail()
