@@ -1,5 +1,3 @@
-import os
-
 import pytest
 
 from enough import settings
@@ -12,19 +10,14 @@ def pytest_configure(config):
 
 
 @pytest.fixture(scope='session')
-def openstack_provider(request):
+def openstack_variables(request):
     ansible = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR)
-    # enforce 'small' flavor
     os_variables = ('openstack_flavor', 'openstack_image', 'openstack_network',
                     'network_primary_interface', 'network_secondary_interface',
                     '_provider')
     os_variables = "{%s}" % ', '.join(f'"{x}": {x}' for x in os_variables)
-    try:
-        os.environ['ENOUGH_PROVIDER'] = request.config.option.provider
-        # Any host could be used
-        hostvars = ansible.get_variable(os_variables, 'bind-host')
-    finally:
-        del os.environ['ENOUGH_PROVIDER']
+    # Any host could be used
+    hostvars = ansible.get_variable(os_variables, 'bind-host')
     hostvars['openstack_provider'] = hostvars.pop('_provider')
     return hostvars
 
@@ -32,7 +25,6 @@ def openstack_provider(request):
 @pytest.fixture
 def dot_openstack(tmp_config_dir, request):
     domain = settings.CONFIG_DIR.split('/')[-1]
-    provider = request.config.option.provider
-    dot_openstack = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, domain, provider)
+    dot_openstack = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, domain)
     dot_openstack.ensure()
     yield dot_openstack
