@@ -72,6 +72,5 @@ def test_docker_delete(tmpdir, docker_name, tcp_port):
 def test_host_factory(request, tmpdir):
     h = host.host_factory(config_dir=tmpdir, driver='docker', domain='a.b')
     assert type(h).__name__ == 'HostDocker'
-    h = host.host_factory(config_dir=tmpdir, driver='openstack', domain='a.b',
-                          provider=request.config.option.provider)
+    h = host.host_factory(config_dir=tmpdir, driver='openstack', domain='a.b')
     assert type(h).__name__ == 'HostOpenStack'
