@@ -11,8 +11,7 @@ def test_ssh(openstack_name, openstack_provider, tmpdir):
     domain = 'enough.community'
     d = Heat.hostvars_to_stack(openstack_name, openstack_provider)
     config_dir = prepare_config_dir(domain, tmpdir)
-    provider = openstack_provider['openstack_provider']
-    ssh = SSH(config_dir, domain=domain, provider=provider)
+    ssh = SSH(config_dir, domain=domain)
     s = Stack(config_dir, d)
     s.set_public_key(f'{config_dir}/infrastructure_key.pub')
     s.create_or_update()
