@@ -1,7 +1,7 @@
 from enough import cmd
 
 
-def test_backup_restore(mocker):
+def test_backup_restore(mocker, tmp_config_dir):
     # do not tamper with logging streams to avoid
     # ValueError: I/O operation on closed file.
     mocker.patch('cliff.app.App.configure_logging')
@@ -9,7 +9,7 @@ def test_backup_restore(mocker):
     assert cmd.main(['--debug', 'backup', 'restore', 'name']) == 0
 
 
-def test_backup_clone_volume(mocker):
+def test_backup_clone_volume(mocker, tmp_config_dir):
     # do not tamper with logging streams to avoid
     # ValueError: I/O operation on closed file.
     mocker.patch('cliff.app.App.configure_logging')
