@@ -36,8 +36,7 @@ class IcingaHelper(object):
 
     def get_web_session(self):
         p = ansible_utils.Playbook('.', '.', [self.inventory])
-        username = p.get_variable('wazuh_api_username', 'wazuh-host')
-        password = p.get_variable('wazuh_api_password', 'wazuh-host')
+        username = list(p.get_role_variables('icinga2', 'icingaweb2_user').values())[0]
         password = list(p.get_role_variables('icinga2', 'icingaweb2_user_pass').values())[0]
         address = self.get_address()
         session = requests.Session()
