@@ -26,32 +26,21 @@ function prepare_repository() {
 }
 
 function prepare_inventory() {
-    if ! test -f inventory/group_vars/all/clouds.yml ; then
-        if test -z "$OS_AUTH_URL" ; then
-            echo OS_AUTH_URL is not set, source openrc.sh
-            exit 1
-        fi
-        cat > tests/clouds.yml <<EOF
----
+    if test "$GITLAB_CI" ; then
+	cat > tests/clouds.yml <<EOF
 clouds:
   production:
-    auth: &os_auth
-      auth_url: "$OS_AUTH_URL"
-      project_name: "${OS_PROJECT_NAME:-$OS_TENANT_NAME}"
-      project_id: "${OS_PROJECT_ID:-$OS_TENANT_ID}"
-      user_domain_name: "$OS_USER_DOMAIN_NAME"
-      username: "$OS_USERNAME"
-      password: "$OS_PASSWORD"
-    region_name: "$OS_REGION_NAME"
-  clone:
     auth:
-      <<: *os_auth
-    region_name: "DE1"
+      auth_url: "https://auth.cloud.ovh.net/v3/"
+      project_name: "AAAAAAA"
+      project_id: "BBBBB"
+      user_domain_name: "CCCCCCC"
+      username: "DDDDDDD"
+      password: "EEEEEEEE"
+    region_name: "FFFFFF"
 EOF
-        cp tests/clouds.yml inventory/group_vars/all/clouds.yml
-    else
-        cat inventory/group_vars/all/clouds.yml > tests/clouds.yml
     fi
+    cp -a tests/clouds.yml inventory/group_vars/all/clouds.yml
 
     if ! test -f inventory/group_vars/all/domain.yml ; then
         cat > tests/domain.yml <<EOF
@@ -112,7 +101,7 @@ function run_tests() {
 	local interactive=-ti
     fi
     container_name="$name-$(date +%s)"
-    docker run $interactive --rm --device=/dev/net/tun --name $container_name --user "${USER:-root}" -e PYTEST_ADDOPTS="${PYTEST_ADDOPTS-}" -e ENOUGH_PROVIDER=$ENOUGH_PROVIDER -e ENOUGH_API_TOKEN=$ENOUGH_API_TOKEN ${PASS_GITLAB_CI} --cap-add=NET_ADMIN $args --volume /var/run/docker.sock:/var/run/docker.sock $name "${@:-tox}"
+    docker run $interactive --rm --device=/dev/net/tun --name $container_name --user "${USER:-root}" -e PYTEST_ADDOPTS="${PYTEST_ADDOPTS-}" -e ENOUGH_API_TOKEN=$ENOUGH_API_TOKEN ${PASS_GITLAB_CI} --cap-add=NET_ADMIN $args --volume /var/run/docker.sock:/var/run/docker.sock $name "${@:-tox}"
 }
 
 function main() {
